<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Security.Authentication.OnlineId

Windows Runtime (WinRT) APIs for for the `Windows.Security.Authentication.OnlineId` namespace.

This package provides the `winrt.windows.security.authentication.onlineid` module.
